@@ -25,5 +25,5 @@ def parse_args(subparsers):
 
 async def _main(args):
     ebus = create_ebus(args)
-    async for line in ebus.cmd(args.cmd, infinite=args.infinite, check=not args.infinite):
+    async for line in ebus.async_cmd(args.cmd, infinite=args.infinite, check=not args.infinite):
         print(line)
