@@ -71,6 +71,7 @@ class Connection:
         _LOGGER.debug("disconnect()")
         if self._writer:
             try:
+                await self._async_write("quit")
                 self._writer.close()
                 await self._writer.wait_closed()
             except BrokenPipeError:  # pragma: no cover
@@ -102,7 +103,13 @@ class Connection:
         await self._async_write(message)
 
     async def async_request(self, cmd, *args, **kwargs):
-        """Assemble request starting with `cmd` and position `args` and keywords `kwargs'."""
+        """
+        Assemble request starting with `cmd` and position `args` and keywords `kwargs'.
+
+        Raises:
+            ConnectionRefusedError: If connection cannot be established
+            ConnectionError: If not connected (`autoconnect==False`)
+        """
         parts = [cmd]
         parts += [f"-{option} {value}" for option, value in kwargs.items() if value is not None]
         parts += [str(arg) for arg in args]
@@ -122,7 +129,7 @@ class Connection:
             ConnectionRefusedError: If connection cannot be established
             ConnectionError: If not connected (`autoconnect==False`)
             CommandError: If command failed (`check==True`)
-            EbusdShutdown: On EBUSD shutdown.
+            Shutdown: On EBUSD shutdown.
         """
         _LOGGER.debug(f"read(infinite={infinite!r}, check={check!r})")
         await self._async_ensure_connection()
@@ -145,7 +152,7 @@ class Connection:
             ConnectionRefusedError: If connection cannot be established
             ConnectionError: If not connected (`autoconnect==False`)
             CommandError: If command failed (`check==True`) or trailing data.
-            EbusdShutdown: On EBUSD shutdown.
+            Shutdown: On EBUSD shutdown.
         """
         _LOGGER.debug(f"readresp(check={check!r})")
         await self._async_ensure_connection()
@@ -164,7 +171,7 @@ class Connection:
         line = line.decode("utf-8").rstrip()
         _LOGGER.debug(f"_readline() = {line!r}")
         if line == "ERR: shutdown":
-            raise EbusdShutdown()
+            raise Shutdown()
         if check and line.startswith("ERR: "):
             raise CommandError(line.lstrip("ERR: "))
         return line
@@ -192,9 +199,6 @@ class CommandError(RuntimeError):
     """Command Error raised in case of EBUSD error, typically if the response starts with `ERR:`"""
 
 
-class EbusdShutdown(ConnectionError):
+class Shutdown(ConnectionError):
 
-    """Shutdown."""
-
-    def __str__(self):
-        return "EBUSD Shutdown."
+    """EBUS Shutdown."""
