@@ -66,7 +66,7 @@ class Ebus:
         self.msgdefcodes = msgdefcodes or []
         self._msgdecoder = MsgDecoder(msgdefs or MsgDefs())
         self.circuitinfos = circuitinfos or []
-        _LOGGER.info(f"{self}")
+        _LOGGER.info(repr(self))
 
     def __repr__(self):
         return repr_(
@@ -116,7 +116,10 @@ class Ebus:
 
     def get_circuitinfo(self, circuit):
         """Return :any:`CircuitInfo` for `circuit`."""
-        return self._circuitinfomap[circuit]
+        try:
+            return self._circuitinfomap[circuit]
+        except KeyError:
+            return None
 
     @property
     def msgdefs(self):
@@ -202,7 +205,7 @@ class Ebus:
                 try:
                     msgdef = decode_msgdef(line)
                 except ValueError as exc:
-                    _LOGGER.warning(f"Cannot decode message definition '{line}' ({exc})")
+                    _LOGGER.warning("Cannot decode message definition %r (%s)", line, exc)
                 if not msgdef.circuit.startswith("scan"):
                     msgdefcodes.append(line)
 
@@ -215,7 +218,7 @@ class Ebus:
             try:
                 msgdefs.append(decode_msgdef(msgdefcode))
             except ValueError as exc:
-                _LOGGER.warning(f"Cannot decode message definition '{msgdefcode}' ({exc})")
+                _LOGGER.warning("Cannot decode message definition %r (%s)", msgdefcode, exc)
         # Sort
         self.msgdefs.clear()
         for msgdef in sorted(msgdefs, key=lambda msgdef: (msgdef.circuit, msgdef.name)):
@@ -242,7 +245,7 @@ class Ebus:
             CommandError: If command failed
             Shutdown: On EBUSD shutdown.
         """
-        _LOGGER.info(f"read({msgdef!r}, ttl={ttl!r})")
+        _LOGGER.info("read(%r, ttl=%r), setprio=%r", msgdef, ttl, setprio)
         if setprio:
             msgdef = msgdef.replace(setprio=resolve_prio(msgdef, setprio))
         return await self._async_read(msgdef, ttl)
@@ -265,14 +268,14 @@ class Ebus:
             ConnectionRefusedError: If connection cannot be established
             ConnectionError: On connection breakdown.
         """
-        _LOGGER.info(f"write({msgdef!r}, value={value!r}, ttl={ttl!r})")
+        _LOGGER.info("write(%r, value=%r, ttl=%r)", msgdef, value, ttl)
         if not msgdef.write:
-            raise ValueError(f"Message is not writeable '{msgdef}'")
+            raise ValueError(f"Message is not writeable {msgdef}")
         fullmsgdef = self.msgdefs.get(msgdef.circuit, msgdef.name)
         if len(fullmsgdef.children) != len(msgdef.children):
             # Read
             if not msgdef.read:
-                raise ValueError(f"Message is not read-modify-writable '{msgdef}'")
+                raise ValueError(f"Message is not read-modify-writable {msgdef}")
             await self.connection.async_request("read", msgdef.name, c=msgdef.circuit, m=ttl)
             line = await self.connection.async_readresp(check=False)
             values = line.split(";")
@@ -306,7 +309,7 @@ class Ebus:
             CommandError: If command failed
             Shutdown: On EBUSD shutdown.
         """
-        _LOGGER.info(f"listen(msgdefs={msgdefs!r})")
+        _LOGGER.info("listen(msgdefs=%r)", msgdefs)
         async for msg in self._async_listen(msgdefs):
             yield msg
 
@@ -331,7 +334,7 @@ class Ebus:
             CommandError: If command failed
             Shutdown: On EBUSD shutdown.
         """
-        _LOGGER.info(f"observe(msgdefs={msgdefs!r}, ttl={ttl!r})")
+        _LOGGER.info("observe(msgdefs=%r, ttl=%r, setprio=%r)", msgdefs, ttl, setprio)
         msgdefs = msgdefs or self.msgdefs
         data = collections.defaultdict(lambda: None)
 
@@ -341,7 +344,7 @@ class Ebus:
                 if setprio:
                     msgdef = msgdef.replace(setprio=resolve_prio(msgdef, setprio))
                 msg = await self._async_read(msgdef, ttl=ttl)
-                _LOGGER.debug("observe-read: {msg}")
+                _LOGGER.debug("observe-read: %r", msg)
                 msg = filter_msg(msg, msgdefs)
                 if msg:
                     if msg.valid:
@@ -354,7 +357,7 @@ class Ebus:
         await self.connection.async_request("find -d")
         async for line in self.connection.async_read(check=False):
             msg = self._decode_msg(line)
-            _LOGGER.debug("observe-find: {msg}")
+            _LOGGER.debug("observe-find: %r", msg)
             msg = filter_msg(msg, msgdefs)
             if msg and msg != data[msg.msgdef.ident]:
                 yield msg
@@ -362,7 +365,7 @@ class Ebus:
 
         # listen
         async for msg in self._async_listen(msgdefs):
-            _LOGGER.debug("observe-listen: {msg}")
+            _LOGGER.debug("observe-listen: %r", msg)
             yield msg
 
     async def async_get_state(self):
