@@ -58,10 +58,7 @@ def iter_virtfielddefs(fielddefs):
 def _merge_date_time(date, time, state=None):
     if date not in (None, NA) and time not in (None, NA):
         if state in (None, "valid", "ok"):
-            if date and time:
-                return datetime.datetime(date.year, date.month, date.day, time.hour, time.minute, time.second)
-            else:
-                return NA
+            return datetime.datetime(date.year, date.month, date.day, time.hour, time.minute, time.second)
         else:
             return state
     return NA
